==> snortsms-0.14.9.tbz: www/snortsms/fbx_Circuits.php <==
<?php
/*
Fusebox Software License
Version 1.0

Copyright (c) 2001-2005 The Fusebox Corporation. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form or otherwise encrypted form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

3. The end-user documentation included with the redistribution, if any, must include the following acknowledgment:

"This product includes software developed by the Fusebox Corporation (http://www.fusebox.org/)."

Alternately, this acknowledgment may appear in the software itself, if and wherever such third-party acknowledgments normally appear.

4. The names "Fusebox" and "Fusebox Corporation" must not be used to endorse or promote products derived from this software without prior written (non-electronic) permission. For written permission, please contact fusebox@fusebox.org.

5. Products derived from this software may not be called "Fusebox", nor may "Fusebox" appear in their name, without prior written (non-electronic) permission of the Fusebox Corporation. For written permission, please contact fusebox@fusebox.org.

If one or more of the above conditions are violated, then this license is immediately revoked and can be re-instated only upon prior written authorization of the Fusebox Corporation.

THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE FUSEBOX CORPORATION OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

--------------------------------------------------------------------------------

This software consists of voluntary contributions made by many individuals on behalf of the Fusebox Corporation. For more information on Fusebox, please see <http://www.fusebox.org/>.
*/

/*<fusedoc fuse="fbx_Circuits.php">
	<responsibilities>
	I define the Circuits structure used with Fusebox 3.0.  Use slashes ("/") to delimit the circuit mapping, 
	i.e.: $Fusebox["circuits"]["red"] = "home/folder/redCircuit";
	</responsibilities>
	<io>
	<out>	
	<string name="$Fusebox['circuits'][*]" comments="set a variable for each circuit name" />
	</out>
	</io>
</fusedoc>*///

$Fusebox["circuits"]["home"]				= "home/main";
$Fusebox["circuits"]["import"] 			= "home/import";
$Fusebox["circuits"]["rules"]				= "home/rules";
$Fusebox["circuits"]["ruletypes"]		= "home/ruletypes";
$Fusebox["circuits"]["variables"] 		= "home/variables";
$Fusebox["circuits"]["references"]		= "home/references";
$Fusebox["circuits"]["classifications"]	= "home/classifications";
$Fusebox["circuits"]["preprocessors"]	= "home/preprocessors";
$Fusebox["circuits"]["outputs"]			= "home/outputs";
$Fusebox["circuits"]["sensors"]			= "home/sensors";
$Fusebox["circuits"]["policies"]			= "home/policies";
$Fusebox["circuits"]["barnyard"]			= "home/barnyard";
$Fusebox["circuits"]["snortctrl"]			= "home/snortctrl";
$Fusebox["circuits"]["barnctrl"]			= "home/barnctrl";
$Fusebox["circuits"]["conf"]				= "home/conf";
$Fusebox["circuits"]["monitor"]			= "home/monitor";
$Fusebox["circuits"]["sensorconf"]		= "home/sensorconf";
$Fusebox["circuits"]["events"]		= "home/events";
?>

==> snortsms-1.0.0.tbz: www/snortsms/fbx_Circuits.php <==
<?php
/*
Fusebox Software License
Version 1.0

Copyright (c) 2001-2005 The Fusebox Corporation. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form or otherwise encrypted form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

3. The end-user documentation included with the redistribution, if any, must include the following acknowledgment:

"This product includes software developed by the Fusebox Corporation (http://www.fusebox.org/)."

Alternately, this acknowledgment may appear in the software itself, if and wherever such third-party acknowledgments normally appear.

4. The names "Fusebox" and "Fusebox Corporation" must not be used to endorse or promote products derived from this software without prior written (non-electronic) permission. For written permission, please contact fusebox@fusebox.org.

5. Products derived from this software may not be called "Fusebox", nor may "Fusebox" appear in their name, without prior written (non-electronic) permission of the Fusebox Corporation. For written permission, please contact fusebox@fusebox.org.

If one or more of the above conditions are violated, then this license is immediately revoked and can be re-instated only upon prior written authorization of the Fusebox Corporation.

THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE FUSEBOX CORPORATION OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

--------------------------------------------------------------------------------

This software consists of voluntary contributions made by many individuals on behalf of the Fusebox Corporation. For more information on Fusebox, please see <http://www.fusebox.org/>.
*/

/*<fusedoc fuse="fbx_Circuits.php">
	<responsibilities>
	I define the Circuits structure used with Fusebox 3.0.  Use slashes ("/") to delimit the circuit mapping, 
	i.e.: $Fusebox["circuits"]["red"] = "home/folder/redCircuit";
	</responsibilities>
	<io>
	<out>	
	<string name="$Fusebox['circuits'][*]" comments="set a variable for each circuit name" />
	</out>
	</io>
</fusedoc>*///

$Fusebox["circuits"]["home"]			= "home/main";
$Fusebox["circuits"]["import"] 			= "home/import";
$Fusebox["circuits"]["rules"]			= "home/rules";
$Fusebox["circuits"]["ruletypes"]		= "home/ruletypes";
$Fusebox["circuits"]["variables"] 		= "home/variables";
$Fusebox["circuits"]["references"]		= "home/references";
$Fusebox["circuits"]["classifications"]	= "home/classifications";
$Fusebox["circuits"]["configs"]			= "home/configs";
$Fusebox["circuits"]["preprocessors"]	= "home/preprocessors";
$Fusebox["circuits"]["outputs"]			= "home/outputs";
$Fusebox["circuits"]["sensors"]			= "home/sensors";
$Fusebox["circuits"]["policies"]		= "home/policies";
$Fusebox["circuits"]["barnyard"]		= "home/barnyard";
$Fusebox["circuits"]["snortctrl"]		= "home/snortctrl";
$Fusebox["circuits"]["barnctrl"]		= "home/barnctrl";
$Fusebox["circuits"]["conf"]			= "home/conf";
$Fusebox["circuits"]["monitor"]			= "home/monitor";
$Fusebox["circuits"]["sensorconf"]		= "home/sensorconf";
$Fusebox["circuits"]["events"]			= "home/events";
$Fusebox["circuits"]["help"]			= "home/help";
?>
